#' Table of Human-->Mouse orthologs for all human genes
#'
#' A dataset containing the MGI and HGNC symbols, Human and Mouse Entrez and Ensembl gene IDs for all human
#' orthologs for mouse genes. Whenin the mouse genes are defined based on a list of all MGI markers from the
#' MGI website (downloaded as MRK_List2.rpt file from http://goo.gl/mjf2GQ)
#'
#' @examples
#' \dontrun{
#' ## The code to prepare the .Rda file file from the marker file is:
#' markers = read.csv("MRK_List2.rpt",sep="\t")
#' genes = markers[markers$Feature.Type=="protein coding gene",]
#' listMarts(host="www.ensembl.org")
#' human <- useMart(host="www.ensembl.org", "ENSEMBL_MART_ENSEMBL", dataset="hsapiens_gene_ensembl")
#' mouse <- useMart(host="www.ensembl.org", "ENSEMBL_MART_ENSEMBL", dataset="mmusculus_gene_ensembl")
#' mouse_to_human_homologs = getLDS(attributes = c("mgi_symbol","entrezgene","ensembl_gene_id"),
#'                                  filters = "mgi_symbol", values = genes$Marker.Symbol,
#'                                  mart = mouse,
#'                                  attributesL = c("hgnc_symbol","ensembl_gene_id","entrezgene"), martL = human)
#' save(mouse_to_human_homologs,file="mouse_to_human_homologs.Rda")
#' }
#'
"mouse_to_human_homologs"

#' Example Gene list
#'
#' A list of genes genetically associated with Alzheimer's disease.
#' @source
#' These were obtained from two sources:
#' http://www.alzgene.org/TopResults.asp and PMID24162737
"example_genelist"

#' Example table of differential expression (Alzheimer's BA46)
#'
#' A list of genes found to be differentially expressed in the BA46 in Alzheimer's disease.
#' @source
#' The table was determined based on data associated with the paper with PMID:17845826
"tt_alzh"

#' Example table of differential expression (Alzheimer's BA36)
#'
#' A list of genes found to be differentially expressed in the BA36 in Alzheimer's disease.
#' @source
#' The table was determined based on data associated with the paper with PMID:17845826
"tt_alzh_BA36"

#' Example table of differential expression (Alzheimer's BA44)
#'
#' A list of genes found to be differentially expressed in the BA44 in Alzheimer's disease.
#' @source
#' The table was determined based on data associated with the paper with PMID:17845826
"tt_alzh_BA44"

#' Subset of genes from Linnarsson lab's cortex single cell transcriptome dataset
#'
#' The first 200 genes from the SCT dataset
#' @source
#' The table was downloaded from the website associated with the paper and loaded using read_celltype_data PMID:25700174
"celltype_data"
